pilas.evento.ProxyEventos

Package pilas :: Module evento :: Class ProxyEventos |
[hide private]
[frames] | no frames]

# Class ProxyEventos

source code

    object --+
             |
            ProxyEventos

Representa el objeto pilas.evento, que internamente delega todos los metodos conectados a la escena actual.

Para acceder a este objeto, usar una sentencia como la siguiente:

    >>> pilas.eventos.click_de_mouse.conectar(una_funcion)

La función enviada como parámetro será invocada cuando el evento ocurra. Y se enviará como argumento los datos del evento, por ejemplo:

    >>> def cuando_hace_click(evento):
    ...     print evento.x
    ...     print evento.y
    ...
    >>> pilas.eventos.click_de_mouse.conectar(cuando_hace_click)

Instance Methods | [hide private]
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
| click_de_mouse Informa ante la pulsación del mouse.
| mueve_camara Informa que ha cambiado la posición de la cámara.
| mueve_mouse Informa que la posición del mouse ha cambiado.
| termina_click Informa cuando la pulsación del mouse termina.
| mueve_rueda Indica que cambió la rueda del mouse que se utiliza para desplazamiento o scroll.
| pulsa_tecla Informa que se ha pulsado una tecla del teclado.
| suelta_tecla Informa que se ha soltado una tecla del teclado.
| pulsa_tecla_escape Indica que se ha pulsado la tecla ``scape``.
| actualizar Se invoca regularmente, 60 veces por segundo.
| log Indica que se emitió un mensaje para depuración usando la función ``pilas.log``.
| Evento
Inherited from `object`: `__class__`

Property Details | [hide private]

### click_de_mouse Informa ante la pulsación del mouse. :param x: Posición horizontal del mouse. :param y: Posición vertical del mouse. :param dx: Posición horizontal relativa del mouse. :param dy: Posición vertical relativa del mouse. :param boton: Botón del mouse que se pulsó (1 - Izquierdo, 2 - Derecho, 4 - Central) Get Method: unreachable.click_de_mouse(self) - Informa ante la pulsación del mouse.

### mueve_camara Informa que ha cambiado la posición de la cámara. :param x: Posición horizontal de la cámara. :param y: Posición vertical de la cámara. :param dx: Movimiento relativo horizontal que sufrió la cámara. :param dy: Movimiento relativo vertical que sufrió la cámara. Get Method: unreachable.mueve_camara(self) - Informa que ha cambiado la posición de la cámara.

### mueve_mouse Informa que la posición del mouse ha cambiado. :param x: Posición horizontal del mouse. :param y: Posición vertical del mouse. :param dx: Posición horizontal relativa del mouse. :param dy: Posición vertical relativa del mouse. Get Method: unreachable.mueve_mouse(self) - Informa que la posición del mouse ha cambiado.

### termina_click Informa cuando la pulsación del mouse termina. :param x: Posición horizontal del mouse. :param y: Posición vertical del mouse. :param dx: Posición horizontal relativa del mouse. :param dy: Posición vertical relativa del mouse. :param boton: Botón del mouse que se pulsó (1 - Izquierdo, 2 - Derecho, 4 - Central) Get Method: unreachable.termina_click(self) - Informa cuando la pulsación del mouse termina.

### mueve_rueda Indica que cambió la rueda del mouse que se utiliza para desplazamiento o scroll. :param delta: indica el grado de rotación de la rueda del mouse. Get Method: unreachable.mueve_rueda(self) - Indica que cambió la rueda del mouse que se utiliza para desplazamiento o scroll.

### pulsa_tecla Informa que se ha pulsado una tecla del teclado. :param codigo: Codigo de la tecla normalizado, por ejemplo ``simbolos.m``. :param es_repeticion: Indica si el evento surgió por repetición de teclado. False indica que es la primer pulsación. :param texto: Cadena de texto que indica la tecla pulsada, por ejemplo ``"m"``. Get Method: unreachable.pulsa_tecla(self) - Informa que se ha pulsado una tecla del teclado.

### suelta_tecla Informa que se ha soltado una tecla del teclado. :param codigo: Codigo de la tecla normalizado, por ejemplo ``simbolos.m``. :param es_repeticion: Indica si el evento surgió por repetición de teclado. False indica que es la primer pulsación. :param texto: Cadena de texto que indica la tecla pulsada, por ejemplo ``"m"``. Get Method: unreachable.suelta_tecla(self) - Informa que se ha soltado una tecla del teclado.

### pulsa_tecla_escape Indica que se ha pulsado la tecla ``scape``. Get Method: unreachable.pulsa_tecla_escape(self) - Indica que se ha pulsado la tecla ``scape``.

### actualizar Se invoca regularmente, 60 veces por segundo. Get Method: unreachable.actualizar(self) - Se invoca regularmente, 60 veces por segundo.

### log Indica que se emitió un mensaje para depuración usando la función ``pilas.log``. Get Method: unreachable.log(self) - Indica que se emitió un mensaje para depuración usando la función ``pilas.log``.

### Evento Get Method: unreachable.Evento(self)